import '@/styles/globals.css';
import { type Metadata } from 'next';
import { Geist } from 'next/font/google';
import {
  AuthContextProvider,
  ThemeProvider,
  TVModeProvider,
  QueryClientProvider,
} from '@/lib/hooks/context';
import PlausibleProvider from 'next-plausible';
import { Toaster } from '@/components/ui';
import * as Sentry from '@sentry/nextjs';

export const generateMetadata = (): Metadata => {
  return {
    title: {
      template: '%s | Next Template',
      default: 'Next Template',
    },
    description: 'Gib\'s Next Template',
    applicationName: 'Next Template',
    keywords: 'Next.js, Supabase, Tailwind, Tanstack, React, Query, T3, Gib',
    authors: [{ name: 'Gib', url: 'https://gbrown.org' }],
    creator: 'Gib Brown',
    publisher: 'Gib Brown',
    other: {
      ...Sentry.getTraceData(),
    },
    formatDetection: {
      email: false,
      address: false,
      telephone: false,
    },
    robots: {
      index: true,
      follow: true,
      nocache: false,
      googleBot: {
        index: true,
        follow: true,
        noimageindex: false,
        'max-video-preview': -1,
        'max-image-preview': 'large',
        'max-snippet': -1,
      },
    },
    icons: {
      icon: [
        { url: '/favicon.ico', type: 'image/x-icon', sizes: 'any' },
        { url: '/favicon-16.png', type: 'image/png', sizes: '16x16' },
        { url: '/favicon-32.png', type: 'image/png', sizes: '32x32' },
        { url: '/favicon.png', type: 'image/png', sizes: '96x96' },
        { url: '/appicon/icon-36.png', type: 'image/png', sizes: '36x36' },
        { url: '/appicon/icon-48.png', type: 'image/png', sizes: '48x48' },
        { url: '/appicon/icon-72.png', type: 'image/png', sizes: '72x72' },
        { url: '/appicon/icon-96.png', type: 'image/png', sizes: '96x96' },
        { url: '/appicon/icon-144.png', type: 'image/png', sizes: '144x144' },
        { url: '/appicon/icon.png', type: 'image/png', sizes: '192x192' },
        /*
        {
          url: '/favicon.ico', type: 'image/x-icon',
          sizes: 'any', media: '(prefers-color-scheme: dark)'
        },
        {
          url: '/favicon-16.png', type: 'image/png',
          sizes: '16x16', media: '(prefers-color-scheme: dark)'
        },
        {
          url: '/favicon-32.png', type: 'image/png',
          sizes: '32x32', media: '(prefers-color-scheme: dark)'
        },
        {
          url: '/favicon.png', type: 'image/png',
          sizes: '96x96', media: '(prefers-color-scheme: dark)'
        },
        {
          url: '/appicon/icon-36.png', type: 'image/png',
          sizes: '36x36', media: '(prefers-color-scheme: dark)'
        },
        {
          url: '/appicon/icon-48.png', type: 'image/png',
          sizes: '48x48', media: '(prefers-color-scheme: dark)'
        },
        {
          url: '/appicon/icon-72.png', type: 'image/png',
          sizes: '72x72', media: '(prefers-color-scheme: dark)'
        },
        {
          url: '/appicon/icon-96.png', type: 'image/png',
          sizes: '96x96', media: '(prefers-color-scheme: dark)'
        },
        {
          url: '/appicon/icon-144.png', type: 'image/png',
          sizes: '144x144', media: '(prefers-color-scheme: dark)'
        },
        {
          url: '/appicon/icon.png', type: 'image/png',
          sizes: '192x192', media: '(prefers-color-scheme: dark)'
        },
        */
      ],
      apple: [
        { url: '/appicon/icon-36.png', type: 'image/png', sizes: '36x36' },
        { url: '/appicon/icon-48.png', type: 'image/png', sizes: '48x48' },
        { url: '/appicon/icon-72.png', type: 'image/png', sizes: '72x72' },
        { url: '/appicon/icon-96.png', type: 'image/png', sizes: '96x96' },
        { url: '/appicon/icon-144.png', type: 'image/png', sizes: '144x144' },
        { url: '/appicon/icon.png', type: 'image/png', sizes: '192x192' },
        /*
        {
          url: '/appicon/icon-36.png', type: 'image/png',
          sizes: '36x36', media: '(prefers-color-scheme: dark)'
        },
        {
          url: '/appicon/icon-48.png', type: 'image/png',
          sizes: '48x48', media: '(prefers-color-scheme: dark)'
        },
        {
          url: '/appicon/icon-72.png', type: 'image/png',
          sizes: '72x72', media: '(prefers-color-scheme: dark)'
        },
        {
          url: '/appicon/icon-96.png', type: 'image/png',
          sizes: '96x96', media: '(prefers-color-scheme: dark)'
        },
        {
          url: '/appicon/icon-144.png', type: 'image/png',
          sizes: '144x144', media: '(prefers-color-scheme: dark)'
        },
        {
          url: '/appicon/icon.png', type: 'image/png',
          sizes: '192x192', media: '(prefers-color-scheme: dark)'
        },
        */
      ],
      shortcut: [
        { url: '/appicon/icon-36.png', type: 'image/png', sizes: '36x36' },
        { url: '/appicon/icon-48.png', type: 'image/png', sizes: '48x48' },
        { url: '/appicon/icon-72.png', type: 'image/png', sizes: '72x72' },
        { url: '/appicon/icon-96.png', type: 'image/png', sizes: '96x96' },
        { url: '/appicon/icon-144.png', type: 'image/png', sizes: '144x144' },
        { url: '/appicon/icon.png', type: 'image/png', sizes: '192x192' },
        /*
        {
          url: '/appicon/icon-36.png', type: 'image/png',
          sizes: '36x36', media: '(prefers-color-scheme: dark)'
        },
        {
          url: '/appicon/icon-48.png', type: 'image/png',
          sizes: '48x48', media: '(prefers-color-scheme: dark)'
        },
        {
          url: '/appicon/icon-72.png', type: 'image/png',
          sizes: '72x72', media: '(prefers-color-scheme: dark)'
        },
        {
          url: '/appicon/icon-96.png', type: 'image/png',
          sizes: '96x96', media: '(prefers-color-scheme: dark)'
        },
        {
          url: '/appicon/icon-144.png', type: 'image/png',
          sizes: '144x144', media: '(prefers-color-scheme: dark)'
        },
        {
          url: '/appicon/icon.png', type: 'image/png',
          sizes: '192x192', media: '(prefers-color-scheme: dark)'
        },
        */
      ],
    },
    /*
    appleWebApp: {
      title: 'Tech Tracker',
      statusBarStyle: 'black-translucent',
      startupImage: [
        '/appicon/apple/splash-768x1024.png',
        {
          url: '/appicon/apple/splash-1536x2008.png',
          media: '(device-width: 768px) and (device-height: 1024px)'
        },
      ],
    },
    verification: {
      google: 'google',
      yandex: 'yandex',
      yahoo: 'yahoo',
    },
    category: 'technology',
		appLinks: {
			ios: {
				url: 'https://git.gbrown.org/next-template',
				app_store_id: 'org.gbrown.next-template',
			},
			android: {
				package: 'https://git.gbrown.org/next-template',
				app_name: 'app_t3_template',
			},
			web: {
				url: 'https://git.gbrown.org/next-template',
				should_fallback: true,
			},
		},
    */
  };
};

const geist = Geist({
  subsets: ['latin'],
  variable: '--font-geist-sans',
});

export default function RootLayout({
  children,
}: Readonly<{ children: React.ReactNode }>) {
  return (
    <html lang='en' className={`${geist.variable}`} suppressHydrationWarning>
      <body>
        <ThemeProvider
          attribute='class'
          defaultTheme='system'
          enableSystem
          disableTransitionOnChange
        >
          <QueryClientProvider>
            <AuthContextProvider>
              <PlausibleProvider
                domain='nexttemplate.gbrown.org'
                customDomain='https://plausible.gbrown.org'
                trackOutboundLinks
                selfHosted
              >
                  <TVModeProvider>
                      {children}
                      <Toaster />
                  </TVModeProvider>
              </PlausibleProvider>
            </AuthContextProvider>
          </QueryClientProvider>
        </ThemeProvider>
      </body>
    </html>
  );
}
